Documentation
¶
Index ¶
- type CronCommand
- func (c *CronCommand) Arguments() []command.Argument
- func (c *CronCommand) AutocompleteArgs() complete.Predictor
- func (c *CronCommand) AutocompleteFlags() complete.Flags
- func (c *CronCommand) Examples() map[string]string
- func (c *CronCommand) FlagSet() *flag.FlagSet
- func (c *CronCommand) Help() string
- func (c *CronCommand) Name() string
- func (c *CronCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *CronCommand) Run(args []string) int
- func (c *CronCommand) Synopsis() string
- type CronInstallCommand
- func (c *CronInstallCommand) Arguments() []command.Argument
- func (c *CronInstallCommand) AutocompleteArgs() complete.Predictor
- func (c *CronInstallCommand) AutocompleteFlags() complete.Flags
- func (c *CronInstallCommand) Examples() map[string]string
- func (c *CronInstallCommand) FlagSet() *flag.FlagSet
- func (c *CronInstallCommand) Help() string
- func (c *CronInstallCommand) Name() string
- func (c *CronInstallCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *CronInstallCommand) Run(args []string) int
- func (c *CronInstallCommand) Synopsis() string
- type CronNotifyCommand
- func (c *CronNotifyCommand) Arguments() []command.Argument
- func (c *CronNotifyCommand) AutocompleteArgs() complete.Predictor
- func (c *CronNotifyCommand) AutocompleteFlags() complete.Flags
- func (c *CronNotifyCommand) Examples() map[string]string
- func (c *CronNotifyCommand) FlagSet() *flag.FlagSet
- func (c *CronNotifyCommand) Help() string
- func (c *CronNotifyCommand) Name() string
- func (c *CronNotifyCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *CronNotifyCommand) Run(args []string) int
- func (c *CronNotifyCommand) Synopsis() string
- type CronRunCommand
- func (c *CronRunCommand) Arguments() []command.Argument
- func (c *CronRunCommand) AutocompleteArgs() complete.Predictor
- func (c *CronRunCommand) AutocompleteFlags() complete.Flags
- func (c *CronRunCommand) Examples() map[string]string
- func (c *CronRunCommand) FlagSet() *flag.FlagSet
- func (c *CronRunCommand) Help() string
- func (c *CronRunCommand) Name() string
- func (c *CronRunCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *CronRunCommand) Run(args []string) int
- func (c *CronRunCommand) Synopsis() string
- type CronUninstallCommand
- func (c *CronUninstallCommand) Arguments() []command.Argument
- func (c *CronUninstallCommand) AutocompleteArgs() complete.Predictor
- func (c *CronUninstallCommand) AutocompleteFlags() complete.Flags
- func (c *CronUninstallCommand) Examples() map[string]string
- func (c *CronUninstallCommand) FlagSet() *flag.FlagSet
- func (c *CronUninstallCommand) Help() string
- func (c *CronUninstallCommand) Name() string
- func (c *CronUninstallCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *CronUninstallCommand) Run(args []string) int
- func (c *CronUninstallCommand) Synopsis() string
- type DeployCommand
- func (c *DeployCommand) Arguments() []command.Argument
- func (c *DeployCommand) AutocompleteArgs() complete.Predictor
- func (c *DeployCommand) AutocompleteFlags() complete.Flags
- func (c *DeployCommand) Examples() map[string]string
- func (c *DeployCommand) FlagSet() *flag.FlagSet
- func (c *DeployCommand) Help() string
- func (c *DeployCommand) Name() string
- func (c *DeployCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *DeployCommand) Run(args []string) int
- func (c *DeployCommand) Synopsis() string
- type DockerCliPluginMetadataCommand
- func (c *DockerCliPluginMetadataCommand) Arguments() []command.Argument
- func (c *DockerCliPluginMetadataCommand) AutocompleteArgs() complete.Predictor
- func (c *DockerCliPluginMetadataCommand) AutocompleteFlags() complete.Flags
- func (c *DockerCliPluginMetadataCommand) Examples() map[string]string
- func (c *DockerCliPluginMetadataCommand) FlagSet() *flag.FlagSet
- func (c *DockerCliPluginMetadataCommand) Help() string
- func (c *DockerCliPluginMetadataCommand) Name() string
- func (c *DockerCliPluginMetadataCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *DockerCliPluginMetadataCommand) Run(args []string) int
- func (c *DockerCliPluginMetadataCommand) Synopsis() string
- type PluginMetadata
- type RunExecuteCommand
- func (c *RunExecuteCommand) Arguments() []command.Argument
- func (c *RunExecuteCommand) AutocompleteArgs() complete.Predictor
- func (c *RunExecuteCommand) AutocompleteFlags() complete.Flags
- func (c *RunExecuteCommand) Examples() map[string]string
- func (c *RunExecuteCommand) FlagSet() *flag.FlagSet
- func (c *RunExecuteCommand) Help() string
- func (c *RunExecuteCommand) Name() string
- func (c *RunExecuteCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *RunExecuteCommand) Run(args []string) int
- func (c *RunExecuteCommand) Synopsis() string
- type RunListCommand
- func (c *RunListCommand) Arguments() []command.Argument
- func (c *RunListCommand) AutocompleteArgs() complete.Predictor
- func (c *RunListCommand) AutocompleteFlags() complete.Flags
- func (c *RunListCommand) Examples() map[string]string
- func (c *RunListCommand) FlagSet() *flag.FlagSet
- func (c *RunListCommand) Help() string
- func (c *RunListCommand) Name() string
- func (c *RunListCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *RunListCommand) Run(args []string) int
- func (c *RunListCommand) Synopsis() string
- type RunListExecutionsCommand
- func (c *RunListExecutionsCommand) Arguments() []command.Argument
- func (c *RunListExecutionsCommand) AutocompleteArgs() complete.Predictor
- func (c *RunListExecutionsCommand) AutocompleteFlags() complete.Flags
- func (c *RunListExecutionsCommand) Examples() map[string]string
- func (c *RunListExecutionsCommand) FlagSet() *flag.FlagSet
- func (c *RunListExecutionsCommand) Help() string
- func (c *RunListExecutionsCommand) Name() string
- func (c *RunListExecutionsCommand) ParsedArguments(args []string) (map[string]command.Argument, error)
- func (c *RunListExecutionsCommand) Run(args []string) int
- func (c *RunListExecutionsCommand) Synopsis() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CronCommand ¶
CronCommand runs the cron scheduler, spawner, and notifier together
func (*CronCommand) Arguments ¶
func (c *CronCommand) Arguments() []command.Argument
func (*CronCommand) AutocompleteArgs ¶
func (c *CronCommand) AutocompleteArgs() complete.Predictor
func (*CronCommand) AutocompleteFlags ¶
func (c *CronCommand) AutocompleteFlags() complete.Flags
func (*CronCommand) Examples ¶
func (c *CronCommand) Examples() map[string]string
func (*CronCommand) FlagSet ¶
func (c *CronCommand) FlagSet() *flag.FlagSet
func (*CronCommand) Help ¶
func (c *CronCommand) Help() string
func (*CronCommand) Name ¶
func (c *CronCommand) Name() string
func (*CronCommand) ParsedArguments ¶
func (*CronCommand) Run ¶
func (c *CronCommand) Run(args []string) int
func (*CronCommand) Synopsis ¶
func (c *CronCommand) Synopsis() string
type CronInstallCommand ¶
CronInstallCommand generates and installs init system service configs for the cron scheduler
func (*CronInstallCommand) Arguments ¶
func (c *CronInstallCommand) Arguments() []command.Argument
func (*CronInstallCommand) AutocompleteArgs ¶
func (c *CronInstallCommand) AutocompleteArgs() complete.Predictor
func (*CronInstallCommand) AutocompleteFlags ¶
func (c *CronInstallCommand) AutocompleteFlags() complete.Flags
func (*CronInstallCommand) Examples ¶
func (c *CronInstallCommand) Examples() map[string]string
func (*CronInstallCommand) FlagSet ¶
func (c *CronInstallCommand) FlagSet() *flag.FlagSet
func (*CronInstallCommand) Help ¶
func (c *CronInstallCommand) Help() string
func (*CronInstallCommand) Name ¶
func (c *CronInstallCommand) Name() string
func (*CronInstallCommand) ParsedArguments ¶
func (*CronInstallCommand) Run ¶
func (c *CronInstallCommand) Run(args []string) int
func (*CronInstallCommand) Synopsis ¶
func (c *CronInstallCommand) Synopsis() string
type CronNotifyCommand ¶
CronNotifyCommand runs only the cron notifier (Docker event listener and webhook sender)
func (*CronNotifyCommand) Arguments ¶
func (c *CronNotifyCommand) Arguments() []command.Argument
func (*CronNotifyCommand) AutocompleteArgs ¶
func (c *CronNotifyCommand) AutocompleteArgs() complete.Predictor
func (*CronNotifyCommand) AutocompleteFlags ¶
func (c *CronNotifyCommand) AutocompleteFlags() complete.Flags
func (*CronNotifyCommand) Examples ¶
func (c *CronNotifyCommand) Examples() map[string]string
func (*CronNotifyCommand) FlagSet ¶
func (c *CronNotifyCommand) FlagSet() *flag.FlagSet
func (*CronNotifyCommand) Help ¶
func (c *CronNotifyCommand) Help() string
func (*CronNotifyCommand) Name ¶
func (c *CronNotifyCommand) Name() string
func (*CronNotifyCommand) ParsedArguments ¶
func (*CronNotifyCommand) Run ¶
func (c *CronNotifyCommand) Run(args []string) int
func (*CronNotifyCommand) Synopsis ¶
func (c *CronNotifyCommand) Synopsis() string
type CronRunCommand ¶
CronRunCommand runs the cron scheduler and spawner without the notifier
func (*CronRunCommand) Arguments ¶
func (c *CronRunCommand) Arguments() []command.Argument
func (*CronRunCommand) AutocompleteArgs ¶
func (c *CronRunCommand) AutocompleteArgs() complete.Predictor
func (*CronRunCommand) AutocompleteFlags ¶
func (c *CronRunCommand) AutocompleteFlags() complete.Flags
func (*CronRunCommand) Examples ¶
func (c *CronRunCommand) Examples() map[string]string
func (*CronRunCommand) FlagSet ¶
func (c *CronRunCommand) FlagSet() *flag.FlagSet
func (*CronRunCommand) Help ¶
func (c *CronRunCommand) Help() string
func (*CronRunCommand) Name ¶
func (c *CronRunCommand) Name() string
func (*CronRunCommand) ParsedArguments ¶
func (*CronRunCommand) Run ¶
func (c *CronRunCommand) Run(args []string) int
func (*CronRunCommand) Synopsis ¶
func (c *CronRunCommand) Synopsis() string
type CronUninstallCommand ¶
CronUninstallCommand removes installed init system service configs
func (*CronUninstallCommand) Arguments ¶
func (c *CronUninstallCommand) Arguments() []command.Argument
func (*CronUninstallCommand) AutocompleteArgs ¶
func (c *CronUninstallCommand) AutocompleteArgs() complete.Predictor
func (*CronUninstallCommand) AutocompleteFlags ¶
func (c *CronUninstallCommand) AutocompleteFlags() complete.Flags
func (*CronUninstallCommand) Examples ¶
func (c *CronUninstallCommand) Examples() map[string]string
func (*CronUninstallCommand) FlagSet ¶
func (c *CronUninstallCommand) FlagSet() *flag.FlagSet
func (*CronUninstallCommand) Help ¶
func (c *CronUninstallCommand) Help() string
func (*CronUninstallCommand) Name ¶
func (c *CronUninstallCommand) Name() string
func (*CronUninstallCommand) ParsedArguments ¶
func (*CronUninstallCommand) Run ¶
func (c *CronUninstallCommand) Run(args []string) int
func (*CronUninstallCommand) Synopsis ¶
func (c *CronUninstallCommand) Synopsis() string
type DeployCommand ¶
func (*DeployCommand) Arguments ¶
func (c *DeployCommand) Arguments() []command.Argument
func (*DeployCommand) AutocompleteArgs ¶
func (c *DeployCommand) AutocompleteArgs() complete.Predictor
func (*DeployCommand) AutocompleteFlags ¶
func (c *DeployCommand) AutocompleteFlags() complete.Flags
func (*DeployCommand) Examples ¶
func (c *DeployCommand) Examples() map[string]string
func (*DeployCommand) FlagSet ¶
func (c *DeployCommand) FlagSet() *flag.FlagSet
func (*DeployCommand) Help ¶
func (c *DeployCommand) Help() string
func (*DeployCommand) Name ¶
func (c *DeployCommand) Name() string
func (*DeployCommand) ParsedArguments ¶
func (*DeployCommand) Run ¶
func (c *DeployCommand) Run(args []string) int
func (*DeployCommand) Synopsis ¶
func (c *DeployCommand) Synopsis() string
type DockerCliPluginMetadataCommand ¶
type DockerCliPluginMetadataCommand struct {
command.Meta
// Version is the version of the plugin
Version string
}
DockerCliPluginMetadataCommand is the command for the plugin metadata
func (*DockerCliPluginMetadataCommand) Arguments ¶
func (c *DockerCliPluginMetadataCommand) Arguments() []command.Argument
func (*DockerCliPluginMetadataCommand) AutocompleteArgs ¶
func (c *DockerCliPluginMetadataCommand) AutocompleteArgs() complete.Predictor
func (*DockerCliPluginMetadataCommand) AutocompleteFlags ¶
func (c *DockerCliPluginMetadataCommand) AutocompleteFlags() complete.Flags
func (*DockerCliPluginMetadataCommand) Examples ¶
func (c *DockerCliPluginMetadataCommand) Examples() map[string]string
func (*DockerCliPluginMetadataCommand) FlagSet ¶
func (c *DockerCliPluginMetadataCommand) FlagSet() *flag.FlagSet
func (*DockerCliPluginMetadataCommand) Help ¶
func (c *DockerCliPluginMetadataCommand) Help() string
func (*DockerCliPluginMetadataCommand) Name ¶
func (c *DockerCliPluginMetadataCommand) Name() string
func (*DockerCliPluginMetadataCommand) ParsedArguments ¶
func (*DockerCliPluginMetadataCommand) Run ¶
func (c *DockerCliPluginMetadataCommand) Run(args []string) int
func (*DockerCliPluginMetadataCommand) Synopsis ¶
func (c *DockerCliPluginMetadataCommand) Synopsis() string
type PluginMetadata ¶
type PluginMetadata struct {
// SchemaVersion is the schema version of the plugin
SchemaVersion string `json:"SchemaVersion"`
// Vendor is the vendor of the plugin
Vendor string `json:"Vendor"`
// Version is the version of the plugin
Version string `json:"Version"`
// ShortDescription is the short description of the plugin
ShortDescription string `json:"ShortDescription"`
}
PluginMetadata is the metadata for the plugin
type RunExecuteCommand ¶
RunExecuteCommand runs a one-shot service on demand
func (*RunExecuteCommand) Arguments ¶
func (c *RunExecuteCommand) Arguments() []command.Argument
func (*RunExecuteCommand) AutocompleteArgs ¶
func (c *RunExecuteCommand) AutocompleteArgs() complete.Predictor
func (*RunExecuteCommand) AutocompleteFlags ¶
func (c *RunExecuteCommand) AutocompleteFlags() complete.Flags
func (*RunExecuteCommand) Examples ¶
func (c *RunExecuteCommand) Examples() map[string]string
func (*RunExecuteCommand) FlagSet ¶
func (c *RunExecuteCommand) FlagSet() *flag.FlagSet
func (*RunExecuteCommand) Help ¶
func (c *RunExecuteCommand) Help() string
func (*RunExecuteCommand) Name ¶
func (c *RunExecuteCommand) Name() string
func (*RunExecuteCommand) ParsedArguments ¶
func (*RunExecuteCommand) Run ¶
func (c *RunExecuteCommand) Run(args []string) int
func (*RunExecuteCommand) Synopsis ¶
func (c *RunExecuteCommand) Synopsis() string
type RunListCommand ¶
RunListCommand lists one-shot services available to run
func (*RunListCommand) Arguments ¶
func (c *RunListCommand) Arguments() []command.Argument
func (*RunListCommand) AutocompleteArgs ¶
func (c *RunListCommand) AutocompleteArgs() complete.Predictor
func (*RunListCommand) AutocompleteFlags ¶
func (c *RunListCommand) AutocompleteFlags() complete.Flags
func (*RunListCommand) Examples ¶
func (c *RunListCommand) Examples() map[string]string
func (*RunListCommand) FlagSet ¶
func (c *RunListCommand) FlagSet() *flag.FlagSet
func (*RunListCommand) Help ¶
func (c *RunListCommand) Help() string
func (*RunListCommand) Name ¶
func (c *RunListCommand) Name() string
func (*RunListCommand) ParsedArguments ¶
func (*RunListCommand) Run ¶
func (c *RunListCommand) Run(args []string) int
func (*RunListCommand) Synopsis ¶
func (c *RunListCommand) Synopsis() string
type RunListExecutionsCommand ¶
RunListExecutionsCommand lists past and running one-shot service executions
func (*RunListExecutionsCommand) Arguments ¶
func (c *RunListExecutionsCommand) Arguments() []command.Argument
func (*RunListExecutionsCommand) AutocompleteArgs ¶
func (c *RunListExecutionsCommand) AutocompleteArgs() complete.Predictor
func (*RunListExecutionsCommand) AutocompleteFlags ¶
func (c *RunListExecutionsCommand) AutocompleteFlags() complete.Flags
func (*RunListExecutionsCommand) Examples ¶
func (c *RunListExecutionsCommand) Examples() map[string]string
func (*RunListExecutionsCommand) FlagSet ¶
func (c *RunListExecutionsCommand) FlagSet() *flag.FlagSet
func (*RunListExecutionsCommand) Help ¶
func (c *RunListExecutionsCommand) Help() string
func (*RunListExecutionsCommand) Name ¶
func (c *RunListExecutionsCommand) Name() string
func (*RunListExecutionsCommand) ParsedArguments ¶
func (*RunListExecutionsCommand) Run ¶
func (c *RunListExecutionsCommand) Run(args []string) int
func (*RunListExecutionsCommand) Synopsis ¶
func (c *RunListExecutionsCommand) Synopsis() string